[game-data-packager] 01/01: codespell

Alexandre Detiste detiste-guest at moszumanska.debian.org
Sun Nov 8 23:05:59 UTC 2015


This is an automated email from the git hooks/post-receive script.

detiste-guest pushed a commit to branch master
in repository game-data-packager.

commit b1d88fd6909ed450fe1f13d75c17ccb8ade2b23d
Author: Alexandre Detiste <alexandre.detiste at gmail.com>
Date:   Mon Nov 9 00:05:38 2015 +0100

    codespell
---
 data/atlantis.yaml                  | 2 +-
 data/compet-n.yaml                  | 2 +-
 data/descent2.yaml                  | 2 +-
 data/draci.yaml                     | 2 +-
 data/hugo.yaml                      | 2 +-
 game_data_packager/__init__.py      | 2 +-
 game_data_packager/build.py         | 4 ++--
 game_data_packager/make_template.py | 4 ++--
 8 files changed, 10 insertions(+), 10 deletions(-)

diff --git a/data/atlantis.yaml b/data/atlantis.yaml
index 17bd833..a30c996 100644
--- a/data/atlantis.yaml
+++ b/data/atlantis.yaml
@@ -11,7 +11,7 @@ gog:
 
 help_text: |
   The non-english versions available on GOG.com are not always the best ones.
-  For exemple, the German & Spanish packages are the
+  For example, the German & Spanish packages are the
   floppy disk versions that lack dubbing.
 
   If you have a .sog / .so3 file whose checksums
diff --git a/data/compet-n.yaml b/data/compet-n.yaml
index 8f2a135..7dd8cfa 100644
--- a/data/compet-n.yaml
+++ b/data/compet-n.yaml
@@ -8,7 +8,7 @@ fanmade: True
 
 help_text: |
   This is a selection of high-quality Doom and Doom II PWADS made
-  by various individuals and choosen by an online poll on the
+  by various individuals and chosen by an online poll on the
   Compet-N speedrunning contest website.
 
   Old website:
diff --git a/data/descent2.yaml b/data/descent2.yaml
index 0feac9a..4cc09d1 100644
--- a/data/descent2.yaml
+++ b/data/descent2.yaml
@@ -101,7 +101,7 @@ files:
       format: innoextract
       # archive also include huge file:
       # - "app/DESCENT_II.gog" (427 MiB)
-      # described in DESCENT_II.inst as beeing an audio-cd rip,
+      # described in DESCENT_II.inst as being an audio-cd rip,
       # which is itself used in dosboxDescent2_client.conf
       # 'imgmount d "..\DESCENT_II.inst" -t iso -fs iso'
     provides:
diff --git a/data/draci.yaml b/data/draci.yaml
index 7ded398..64a6a60 100644
--- a/data/draci.yaml
+++ b/data/draci.yaml
@@ -10,7 +10,7 @@ wiki: Draci
 # - music too loud ?
 
 help_text: | 
-  Dragon History is a Czech adventure game developped in 1995.
+  Dragon History is a Czech adventure game developed in 1995.
 
   The main hero is a little dragon called Bert,
   who is searching for his father that disappeared a short time ago,
diff --git a/data/hugo.yaml b/data/hugo.yaml
index 1098795..19133e2 100644
--- a/data/hugo.yaml
+++ b/data/hugo.yaml
@@ -111,7 +111,7 @@ files:
     - hw_hint3.txt
 
 size_and_md5: |
-  # the Linux archive is much bigger, but has the same usefull contents
+  # the Linux archive is much bigger, but has the same useful contents
   25134308  e579e38e0220ea74b94abadcf475465a gog_the_hugo_trilogy_2.0.0.10.sh
   15796401  5da4ca64a236b3b2b421bb6c389e0cdd setup_the_hugo_trilogy_2.0.0.1.exe
   876       3f99a3fc46c317924047e22e3b2985e3 hugo.bsf
diff --git a/game_data_packager/__init__.py b/game_data_packager/__init__.py
index 5bf6bc1..46312cc 100644
--- a/game_data_packager/__init__.py
+++ b/game_data_packager/__init__.py
@@ -662,7 +662,7 @@ class GameData(object):
                 help_text += "         is accessible simultaneously, e.g. copy data from CD1 to CD3 in /tmp/cd{1-3}\n"
                 help_text += "         and let CD4 *mounted* in the drive.\n\n"
                 help_text += "         It's important to first mkdir '/tmp/cd1 /tmp/cd2 /tmp/cd3' because for some\n"
-                help_text += "         games there are different files accross the disks with the same name that\n"
+                help_text += "         games there are different files across the disks with the same name that\n"
                 help_text += "         would be overwriten.\n\n"
                 help_text += "         If /tmp/ is on a tmpfs and you don't have something like 16GB of RAM,\n"
                 help_text += "         you'll likely need to store the files somewhere else.\n\n"
diff --git a/game_data_packager/make_template.py b/game_data_packager/make_template.py
index e840992..7146626 100644
--- a/game_data_packager/make_template.py
+++ b/game_data_packager/make_template.py
@@ -48,7 +48,7 @@ logger = logging.getLogger('game_data_packager.make-template')
 
 # I guess there is a minimum size under which a
 # MD5 collision is not possible and having
-# a SHA1 for these files is not usefull
+# a SHA1 for these files is not useful
 MD5_SAFE_ENOUGH = 5000
 
 def guess_lang(string):
@@ -150,7 +150,7 @@ class GameData(object):
         self.gog_path = None
 
         self.data = dict()
-        # global list of files accross packages
+        # global list of files across packages
         self.install = set()
         self.optional = set()
         self.doc = set()

diff --git a/game_data_packager/build.py b/game_data_packager/build.py
index b66e03a..fccd663 100644
--- a/game_data_packager/build.py
+++ b/game_data_packager/build.py
@@ -2207,7 +2207,7 @@ class PackagingTask(object):
                                 package.name, package.lang)
                     possible.discard(package)
                     continue
                 # keep only prefered language for this virtual package
                 if package.provides:
                     for other_p in possible:
                         if other_p.name == package.name:
@@ -2216,7 +2216,7 @@ class PackagingTask(object):
                             continue
                         if score < lang_score(other_p.lang):
                             logger.info('will not produce "%s" '
-                                        'because "%s" is prefered language',
+                                        'because "%s" is preferred language',
                                         package.name, other_p.lang)
                             possible.discard(package)
                             break
@@ -2207,7 +2207,7 @@ class PackagingTask(object):
                     possible.discard(package)
                     continue
-                # keep only prefered language for this virtual package
+                # keep only preferred language for this virtual package
                 if package.provides:
                     for other_p in possible:
-- 
Alioth's /usr/local/bin/git-commit-notice on /srv/git.debian.org/git/pkg-games/game-data-packager.git



More information about the Pkg-games-commits mailing list